@@ -1,5 +1,5 @@
 Clazz.declarePackage ("J.shapespecial");
-Clazz.load (["J.shape.AtomShape", "JU.AU", "$.BS", "$.P3", "$.V3"], "J.shapespecial.Polyhedra", ["java.lang.Boolean", "$.Float", "java.util.Arrays", "$.Hashtable", "JU.Lst", "$.Measure", "$.P4", "$.PT", "$.SB", "J.c.PAL", "J.shapespecial.Polyhedron", "JU.BSUtil", "$.C", "$.Logger", "$.Normix"], function () {
+Clazz.load (["J.shape.AtomShape", "JU.AU", "$.BS", "$.P3", "$.V3"], "J.shapespecial.Polyhedra", ["java.lang.Boolean", "$.Float", "java.util.Arrays", "$.Hashtable", "JU.Lst", "$.Measure", "$.P4", "$.PT", "$.SB", "J.api.Interface", "J.c.PAL", "J.shapespecial.Polyhedron", "JU.BSUtil", "$.C", "$.Logger", "$.Normix"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.otherAtoms = null;
 this.normalsT = null;
@@ -29,6 +29,7 @@ this.info = null;
 this.distanceRef = 0;
 this.modelIndex = 0;
 this.isAuto = false;
+this.explicitFaces = null;
 this.bsPolys = null;
 this.vAB = null;
 this.vAC = null;
@@ -69,6 +70,9 @@ this.bsVertexCount =  new JU.BS ();
 this.bondedOnly = this.isCollapsed = this.isFull = this.iHaveCenterBitSet = this.useUnitCell = this.isAuto = this.haveBitSetVertices = false;
 if (Boolean.TRUE === value) this.drawEdges = 0;
 return;
+}if ("definedFaces" === propertyName) {
+this.setDefinedFaces ((value)[1], (value)[0]);
+return;
 }if ("generate" === propertyName) {
 if (!this.iHaveCenterBitSet) {
 this.centers = bs;
@@ -223,6 +227,45 @@ this.polyhedrons = JU.AU.deleteElements (this.polyhedrons, i, 1);
 }}
 }this.setPropAS (propertyName, value, bs);
 }, "~S,~O,JU.BS");
+Clazz.defineMethod (c$, "setDefinedFaces", 
+ function (points, faces) {
+var bsUsed =  new JU.BS ();
+for (var i = faces.length; --i >= 0; ) {
+var face = faces[i];
+for (var j = face.length; --j >= 0; ) bsUsed.set (face[j]);
+
+}
+var bsNot = JU.BSUtil.newBitSet2 (0, bsUsed.length ());
+bsNot.andNot (bsUsed);
+var nNot = bsNot.cardinality ();
+if (nNot > 0) {
+var np = points.length;
+var mapOldToNew =  Clazz.newIntArray (np, 0);
+var mapNewToOld =  Clazz.newIntArray (np, 0);
+var n = 0;
+for (var i = 0; i < np; i++) if (!bsNot.get (i)) {
+mapNewToOld[n] = i;
+mapOldToNew[i] = n++;
+}
+var pnew =  new Array (n);
+for (var i = 0; i < n; i++) pnew[i] = points[mapNewToOld[i]];
+
+points = pnew;
+for (var i = faces.length; --i >= 0; ) {
+var face = faces[i];
+for (var j = face.length; --j >= 0; ) face[j] = mapOldToNew[face[j]];
+
+}
+}var n = this.nPoints = points.length;
+this.center =  new JU.P3 ();
+this.otherAtoms =  new Array (n + 1);
+if (n > 0) {
+this.otherAtoms[n] = this.center;
+for (var i = 0; i < n; i++) this.center.add (this.otherAtoms[i] = points[i]);
+
+this.center.scale (1 / n);
+}this.explicitFaces = faces;
+}, "~A,~A");
 Clazz.defineMethod (c$, "pointsPolyhedra", 
  function (bs, pointScale) {
 bs = this.findPolyBS (this.thisID == null ? bs : null);
@@ -557,8 +600,22 @@ return (iMax == 0 ? otherAtomCount : iMax);
 Clazz.defineMethod (c$, "validatePolyhedron", 
  function (atomOrPt, vertexCount) {
 var points = this.otherAtoms;
+var faces = this.explicitFaces;
+var faceTriangles;
+var normals;
 var collapsed = this.isCollapsed;
 var triangleCount = 0;
+var bsCenterPlanes =  new JU.BS ();
+var triangles;
+if (faces != null) {
+collapsed = false;
+faceTriangles = JU.AU.newInt2 (faces.length);
+normals =  new Array (faces.length);
+for (var i = faces.length; --i >= 0; ) faces[i] = this.fixExplicitFaceWinding (faces[i], i, points, normals);
+
+triangles = (J.api.Interface.getInterface ("JU.MeshCapper", this.vwr, "script")).set (null).triangulateFaces (faces, points, faceTriangles);
+triangleCount = triangles.length;
+} else {
 var nPoints = vertexCount + 1;
 var ni = vertexCount - 2;
 var nj = vertexCount - 1;
@@ -574,17 +631,16 @@ if (this.thisID == null) for (var pt = 0, i = 0; i < ni; i++) for (var j = i + 1
 
 
 
-var triangles = this.planesT;
+triangles = this.planesT;
 var pTemp =  new JU.P4 ();
 var nTemp =  new JU.V3 ();
 var offset = this.faceCenterOffset;
 var fmax = 247;
 var vmax = 250;
 var bsTemp = JU.Normix.newVertexBitSet ();
-var normals = this.normalsT;
+normals = this.normalsT;
 var htNormMap =  new java.util.Hashtable ();
 var htEdgeMap =  new java.util.Hashtable ();
-var bsCenterPlanes =  new JU.BS ();
 var lstRejected = (this.isFull ?  new JU.Lst () : null);
 var edgeTest =  new Array (3);
 var vAC = this.vAC;
@@ -629,10 +685,23 @@ if (JU.Logger.debugging) {
 JU.Logger.info ("Polyhedron planeCount=" + triangleCount + " nPoints=" + nPoints);
 for (var i = 0; i < triangleCount; i++) JU.Logger.info ("Polyhedron " + JU.PT.toJSON ("face[" + i + "]", triangles[i]));
 
-}var faces = this.getFaces (triangles, triangleCount, htNormMap);
-var faceTriangles = this.getFaceTriangles (faces.length, htNormMap, triangleCount);
-return  new J.shapespecial.Polyhedron ().set (this.thisID, this.modelIndex, atomOrPt, points, nPoints, vertexCount, triangles, triangleCount, faces, faceTriangles, normals, bsCenterPlanes, collapsed, this.distanceRef, this.pointScale);
+}faces = this.getFaces (triangles, triangleCount, htNormMap);
+faceTriangles = this.getFaceTriangles (faces.length, htNormMap, triangleCount);
+}return  new J.shapespecial.Polyhedron ().set (this.thisID, this.modelIndex, atomOrPt, points, this.nPoints, vertexCount, triangles, triangleCount, faces, faceTriangles, normals, bsCenterPlanes, collapsed, this.distanceRef, this.pointScale);
 }, "JU.P3,~N");
+Clazz.defineMethod (c$, "fixExplicitFaceWinding", 
+ function (face, ipt, points, normals) {
+var n = face.length;
+for (var i = 0, nlast = n - 2; i < nlast; i++) {
+var a = points[face[i]];
+var b = points[face[(i + 1) % n]];
+var c = points[face[(i + 2) % n]];
+if (JU.Measure.computeAngleABC (a, b, c, true) < 178) {
+if (!JU.Measure.getNormalFromCenter (this.center, a, b, c, true, normals[ipt] =  new JU.V3 (), this.vAC)) face = JU.AU.arrayCopyRangeRevI (face, 0, -1);
+break;
+}}
+return face;
+}, "~A,~N,~A,~A");
 Clazz.defineMethod (c$, "getFaceTriangles", 
  function (n, htNormMap, triangleCount) {
 var faceTriangles = JU.AU.newInt2 (n);
