@@ -1002,6 +1002,10 @@ Clazz.overrideMethod (c$, "setCIPChirality",
 function (c) {
 this.formalChargeAndFlags = (this.formalChargeAndFlags & -4081) | (c << 4);
 }, "~N");
+Clazz.overrideMethod (c$, "getCIPChiralityCode", 
+function () {
+return (this.formalChargeAndFlags & 4080) >> 4;
+});
 Clazz.overrideMethod (c$, "getInsertionCode", 
 function () {
 return this.group.getInsertionCode ();
