@@ -1,11 +1,10 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["JU.Lst", "$.V3"], "JS.CIPChirality", ["java.util.Arrays", "$.Hashtable", "JU.BS", "$.Measure", "$.P3", "$.P4", "$.PT", "JU.BSUtil", "$.Logger", "JV.JC"], function () {
+Clazz.load (["JU.Lst", "$.V3"], "JS.CIPChirality", ["java.util.Arrays", "$.Hashtable", "JU.BS", "$.Measure", "$.P4", "$.PT", "JU.BSUtil", "$.Logger", "JV.JC"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.ptID = 0;
 this.root = null;
 this.currentRule = 1;
 this.lstSmallRings = null;
-this.nPriorityMax = 0;
 this.bsAtropisomeric = null;
 this.bsKekuleAmbiguous = null;
 this.bsAzacyclic = null;
@@ -33,15 +32,15 @@ function () {
 Clazz.defineMethod (c$, "init", 
  function () {
 this.ptID = 0;
-this.nPriorityMax = 0;
 this.lstSmallRings.clear ();
 this.bsKekuleAmbiguous = null;
+this.bsAtropisomeric =  new JU.BS ();
 });
 Clazz.defineMethod (c$, "getChiralityForAtoms", 
-function (atoms, bsAtoms, bsAtropisomeric) {
+function (atoms, bsAtoms, bsAtropisomeric, bsHelixM, bsHelixP) {
 if (bsAtoms.isEmpty ()) return;
-this.bsAtropisomeric = bsAtropisomeric;
 this.init ();
+this.bsAtropisomeric = (bsAtropisomeric == null ?  new JU.BS () : bsAtropisomeric);
 var bs = JU.BSUtil.copy (bsAtoms);
 this.lstSmallRings =  new JU.Lst ();
 while (!bs.isEmpty ()) this.getSmallRings (atoms[bs.nextSetBit (0)], bs);
@@ -53,7 +52,7 @@ var haveAlkenes = this.preFilterAtomList (atoms, bsToDo);
 for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) {
 var a = atoms[i];
 a.setCIPChirality (0);
-var c = this.getAtomChiralityLimited (a, null, null, 7);
+var c = this.getAtomChiralityLimited (a, null, null, 8);
 a.setCIPChirality (c == 0 ? 3 : c);
 }
 if (haveAlkenes) {
@@ -61,10 +60,14 @@ var lstEZ =  new JU.Lst ();
 for (var i = bsToDo.nextSetBit (0); i >= 0; i = bsToDo.nextSetBit (i + 1)) this.getAtomBondChirality (atoms[i], lstEZ, bsToDo);
 
 if (this.lstSmallRings.size () > 0 && lstEZ.size () > 0) this.clearSmallRingEZ (atoms, lstEZ);
+if (bsHelixM != null) for (var i = bsHelixM.nextSetBit (0); i >= 0; i = bsHelixM.nextSetBit (i + 1)) atoms[i].setCIPChirality (33);
+
+if (bsHelixP != null) for (var i = bsHelixP.nextSetBit (0); i >= 0; i = bsHelixP.nextSetBit (i + 1)) atoms[i].setCIPChirality (34);
+
 }if (JU.Logger.debugging) {
 JU.Logger.info ("sp2-aromatic = " + this.bsKekuleAmbiguous);
 JU.Logger.info ("smallRings = " + JU.PT.toJSON (null, this.lstSmallRings));
-}}, "~A,JU.BS,JU.BS");
+}}, "~A,JU.BS,JU.BS,JU.BS,JU.BS");
 Clazz.defineMethod (c$, "getAzacyclic", 
  function (atoms, bsAtoms) {
 var bsAza = null;
@@ -277,7 +280,7 @@ return JU.Measure.distanceToPlane (plane, a.getXYZ ());
 Clazz.defineMethod (c$, "getAtomChirality", 
 function (atom) {
 this.init ();
-var rs = this.getAtomChiralityLimited (atom, null, null, 7);
+var rs = this.getAtomChiralityLimited (atom, null, null, 8);
 return (rs == 0 ? 3 : rs);
 }, "JU.Node");
 Clazz.defineMethod (c$, "getBondChirality", 
@@ -286,7 +289,7 @@ if (bond.getCovalentOrder () != 2) return 0;
 this.init ();
 this.lstSmallRings =  new JU.Lst ();
 this.getSmallRings (bond.getOtherAtomNode (null), null);
-return this.getBondChiralityLimited (bond, null, 7);
+return this.getBondChiralityLimited (bond, null, 8);
 }, "JU.Edge");
 Clazz.defineMethod (c$, "getAtomBondChirality", 
  function (atom, lstEZ, bsToDo) {
@@ -302,12 +305,12 @@ if (isAtropic) {
 atom1 = bonds[j].getOtherAtomNode (atom);
 index1 = atom1.getIndex ();
 if (!this.bsAtropisomeric.get (index1)) continue;
-c = this.getAxialOrEZChirality (atom, atom1, atom, atom1, true, 7);
+c = this.getAxialOrEZChirality (atom, atom1, atom, atom1, true, 8);
 } else if (bond.getCovalentOrder () == 2) {
 atom1 = this.getLastCumuleneAtom (bond, atom, null, null);
 index1 = atom1.getIndex ();
 if (index1 < index) continue;
-c = this.getBondChiralityLimited (bond, atom, 7);
+c = this.getBondChiralityLimited (bond, atom, 8);
 } else {
 continue;
 }if (c != 0) {
@@ -354,7 +357,7 @@ if (cipAtom == null) {
 cipAtom = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (atom, null, false, isAlkene);
 var nSubs = atom.getCovalentBondCount ();
 var elemNo = atom.getElementNumber ();
-isAlkene = (nSubs == 3 && elemNo <= 10 && cipAtom.lonePair == null);
+isAlkene = (nSubs == 3 && elemNo <= 10 && !cipAtom.isTrigonalPyramidal);
 if (nSubs != (parent == null ? 4 : 3) - (nSubs == 3 && !isAlkene ? 1 : 0)) return rs;
 } else {
 atom = cipAtom.atom;
@@ -383,7 +386,7 @@ if (cipAtom.priorities[i] == cipAtom.priorities[i + 1]) {
 isChiral = false;
 break;
 }}
-if (this.currentRule == 7) cipAtom.isPseudo = cipAtom.canBePseudo;
+if (this.currentRule == 8) cipAtom.isPseudo = cipAtom.canBePseudo;
 if (isChiral) {
 rs = (!isAlkene ? cipAtom.checkHandedness () : cipAtom.atoms[0].isDuplicate ? 2 : 1);
 if (!isAlkene && cipAtom.isPseudo && cipAtom.canBePseudo) rs = rs | 4;
@@ -418,7 +421,7 @@ var atop = this.getAlkeneEndTopPriority (a1, pa, isAxial, ruleMax);
 var b2 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (b, null, false, true);
 var btop = this.getAlkeneEndTopPriority (b2, pb, isAxial, ruleMax);
 var c = (atop >= 0 && btop >= 0 ? this.getEneChirality (b2.atoms[btop], b2, a1, a1.atoms[atop], isAxial, true) : 0);
-if (c != 0 && (isAxial || !this.isAtropisomeric (a) && !this.isAtropisomeric (b))) {
+if (c != 0 && (isAxial || !this.bsAtropisomeric.get (a.getIndex ()) && !this.bsAtropisomeric.get (b.getIndex ()))) {
 a.setCIPChirality (c);
 b.setCIPChirality (c);
 if (JU.Logger.debugging) JU.Logger.info (a + "-" + b + " " + JV.JC.getCIPChiralityName (c));
@@ -430,14 +433,9 @@ return (top1 == null || top2 == null || top1.atom == null || top2.atom == null ?
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~B,~B");
 Clazz.defineMethod (c$, "getAlkeneEndTopPriority", 
  function (a1, pa, isAxial, ruleMax) {
-var b1 = Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (pa, null, false, true);
 a1.canBePseudo = a1.isOddCumulene = isAxial;
-return this.getAtomChiralityLimited (a1.atom, a1, b1, ruleMax) - 1;
+return this.getAtomChiralityLimited (a1.atom, a1, Clazz.innerTypeInstance (JS.CIPChirality.CIPAtom, this, null).create (pa, null, false, true), ruleMax) - 1;
 }, "JS.CIPChirality.CIPAtom,JU.Node,~B,~N");
-Clazz.defineMethod (c$, "isAtropisomeric", 
- function (a) {
-return this.bsAtropisomeric != null && this.bsAtropisomeric.get (a.getIndex ());
-}, "JU.Node");
 Clazz.defineMethod (c$, "isCis", 
 function (a, b, c, d) {
 JU.Measure.getNormalThroughPoints (a.atom.getXYZ (), b.atom.getXYZ (), c.atom.getXYZ (), this.vNorm, this.vTemp);
@@ -450,10 +448,6 @@ function (a, b, c, d) {
 var angle = JU.Measure.computeTorsion (a.atom.getXYZ (), b.atom.getXYZ (), c.atom.getXYZ (), d.atom.getXYZ (), true);
 return (angle > 0);
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "sign", 
-function (score) {
-return (score < 0 ? -1 : score > 0 ? 1 : 0);
-}, "~N");
 c$.$CIPChirality$CIPAtom$ = function () {
 Clazz.pu$h(self.c$);
 c$ = Clazz.decorateAsClass (function () {
@@ -486,7 +480,6 @@ this.bondCount = 0;
 this.atoms = null;
 this.priorities = null;
 this.rule4List = null;
-this.lonePair = null;
 this.atomIndex = 0;
 this.auxEZ = -1;
 this.canBePseudo = true;
@@ -498,7 +491,7 @@ this.rule4Count = null;
 this.priority = 0;
 this.htPathPoints = null;
 this.isTrigonalPyramidal = false;
-this.isAromatic = false;
+this.isKekuleAmbiguous = false;
 this.sp2Duplicate = false;
 Clazz.instantialize (this, arguments);
 }, JS.CIPChirality, "CIPAtom", null, [Comparable, Cloneable]);
@@ -517,12 +510,11 @@ if (a == null) return this;
 this.isAlkene = d;
 this.atom = a;
 this.atomIndex = a.getIndex ();
-this.isAromatic = (this.b$["JS.CIPChirality"].bsKekuleAmbiguous != null && this.b$["JS.CIPChirality"].bsKekuleAmbiguous.get (this.atomIndex));
-this.elemNo = (c && this.isAromatic ? this.getKekuleElementNumber (b) : a.getElementNumber ());
+this.isKekuleAmbiguous = (this.b$["JS.CIPChirality"].bsKekuleAmbiguous != null && this.b$["JS.CIPChirality"].bsKekuleAmbiguous.get (this.atomIndex));
+this.elemNo = (c && this.isKekuleAmbiguous ? b.getKekuleElementNumber () : a.getElementNumber ());
 this.massNo = a.getNominalMass ();
 this.bondCount = a.getCovalentBondCount ();
 this.isTrigonalPyramidal = (this.bondCount == 3 && !d && (this.elemNo > 10 || this.b$["JS.CIPChirality"].bsAzacyclic != null && this.b$["JS.CIPChirality"].bsAzacyclic.get (this.atomIndex)));
-if (this.isTrigonalPyramidal) this.getLonePair ();
 this.canBePseudo = (this.bondCount == 4 || this.isTrigonalPyramidal);
 if (b != null) this.sphere = b.sphere + 1;
 if (this.sphere == 1) {
@@ -533,50 +525,39 @@ this.rootSubstituent = b.rootSubstituent;
 this.htPathPoints = this.rootSubstituent.htPathPoints;
 }this.bsPath = (b == null ?  new JU.BS () : JU.BSUtil.copy (b.bsPath));
 this.sp2Duplicate = c;
+this.rootDistance = this.sphere;
 if (b == null) {
 this.bsPath.set (this.atomIndex);
-this.rootDistance = 0;
-} else if (this.sp2Duplicate && this.isAromatic) {
-this.rootDistance = b.rootDistance;
+} else if (this.sp2Duplicate && this.isKekuleAmbiguous) {
 } else if (a === this.b$["JS.CIPChirality"].root.atom) {
-this.rootDistance = 0;
 c = true;
+this.rootDistance = 0;
 } else if (this.bsPath.get (this.atomIndex)) {
 c = true;
-this.rootDistance = this.rootSubstituent.htPathPoints.get (a.toString ()).intValue ();
+this.rootDistance = this.rootSubstituent.htPathPoints.get (Integer.$valueOf (this.atomIndex)).intValue ();
 } else {
 this.bsPath.set (this.atomIndex);
-this.rootDistance = b.rootDistance + 1;
-this.rootSubstituent.htPathPoints.put (a.toString (),  new Integer (this.rootDistance));
+this.rootSubstituent.htPathPoints.put (Integer.$valueOf (this.atomIndex), Integer.$valueOf (this.rootDistance));
 }this.isDuplicate = c;
 if (JU.Logger.debugging) {
-if (this.sphere < 30) this.myPath = (b != null ? b.myPath + "-" : "") + this;
+if (this.sphere < 50) this.myPath = (b != null ? b.myPath + "-" : "") + this;
 JU.Logger.info ("new CIPAtom " + this.myPath);
 }return this;
 }, "JU.Node,JS.CIPChirality.CIPAtom,~B,~B");
 Clazz.defineMethod (c$, "getKekuleElementNumber", 
- function (a) {
-var b = a.atom;
-var c = b.getEdges ();
-var d;
-var e = 0;
-var f = 0;
-for (var g = c.length; --g >= 0; ) if ((d = c[g]).isCovalent ()) {
-var h = d.getOtherAtomNode (b);
-if (this.b$["JS.CIPChirality"].bsKekuleAmbiguous.get (h.getIndex ())) {
-f++;
-e += h.getElementNumber ();
-}}
-return e / f;
-}, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "getLonePair", 
  function () {
-var a = this.b$["JS.CIPChirality"].getTrigonality (this.atom, this.b$["JS.CIPChirality"].vNorm);
-if (Math.abs (a) > 0.2) {
-this.lonePair =  new JU.P3 ();
-this.b$["JS.CIPChirality"].vNorm.scale (a);
-this.lonePair.add2 (this.atom.getXYZ (), this.b$["JS.CIPChirality"].vNorm);
-}});
+var a = this.atom.getEdges ();
+var b;
+var c = 0;
+var d = 0;
+for (var e = a.length; --e >= 0; ) if ((b = a[e]).isCovalent ()) {
+var f = b.getOtherAtomNode (this.atom);
+if (this.b$["JS.CIPChirality"].bsKekuleAmbiguous.get (f.getIndex ())) {
+d++;
+c += f.getElementNumber ();
+}}
+return c / d;
+});
 Clazz.defineMethod (c$, "updateRingList", 
 function () {
 var a = JU.BSUtil.newAndSetBit (this.atomIndex);
@@ -678,7 +659,7 @@ for (var d = 0; d < 4; d++) {
 JU.Logger.info (this.b$["JS.CIPChirality"].getRuleName () + ": " + this + "[" + d + "]=" + this.atoms[d].myPath + " " + Integer.toHexString (b[d]));
 }
 JU.Logger.info ("---");
-}var d = (this.rule4List != null && (this.b$["JS.CIPChirality"].currentRule == 6 || this.b$["JS.CIPChirality"].currentRule == 7));
+}var d = (this.rule4List != null && this.b$["JS.CIPChirality"].currentRule > 5);
 for (var e = 0; e < 4; e++) {
 var f = this.atoms[e];
 for (var g = e + 1; g < 4; g++) {
@@ -704,7 +685,7 @@ this.priorities[g]++;
 if (i) JU.Logger.info (this.dots () + this + "." + f + " A-beats " + h);
 break;
 case 0:
-switch (this.b$["JS.CIPChirality"].sign (j = f.breakTie (h))) {
+switch (this.sign (j = f.breakTie (h))) {
 case 0:
 a[g]++;
 if (i) JU.Logger.info (this.dots () + this + "." + h + " ends up with tie with " + f);
@@ -734,14 +715,12 @@ var h =  new JU.BS ();
 for (var i = 0; i < 4; i++) {
 var j = a[i];
 var k = f[j] = this.atoms[i];
-var l = this.priorities[i];
-g[j] = l;
+g[j] = this.priorities[i];
 if (k.atom != null) h.set (this.priorities[i]);
 }
 this.atoms = f;
 this.priorities = g;
 this.nPriorities = h.cardinality ();
-if (this.nPriorities > this.b$["JS.CIPChirality"].nPriorityMax) this.b$["JS.CIPChirality"].nPriorityMax = this.nPriorities;
 if (this.ties != null && !this.isOddCumulene) {
 switch (this.ties.size ()) {
 case 1:
@@ -864,6 +843,7 @@ case 5:
 return this.checkRules4a (a, " sr SR PM");
 case 6:
 case 7:
+case 8:
 return 0;
 }
 }, "JS.CIPChirality.CIPAtom");
@@ -883,27 +863,36 @@ Clazz.defineMethod (c$, "checkRule3",
  function (a) {
 var b;
 var c;
-return this.parent == null || !this.parent.isAlkeneAtom2 || !a.parent.isAlkeneAtom2 || this.isDuplicate || a.isDuplicate || !this.isCumulativeType (-2) || !a.isCumulativeType (-2) ? -2147483648 : this.parent === a.parent ? this.b$["JS.CIPChirality"].sign (this.breakTie (a)) : (b = this.parent.getEZaux ()) < (c = a.parent.getEZaux ()) ? -1 : b > c ? 1 : 0;
+return this.parent == null || !this.parent.isAlkeneAtom2 || !a.parent.isAlkeneAtom2 || this.isDuplicate || a.isDuplicate || !this.isEvenCumulene () || !a.isEvenCumulene () ? -2147483648 : this.parent === a.parent ? this.sign (this.breakTie (a)) : (b = this.parent.getEZaux ()) < (c = a.parent.getEZaux ()) ? -1 : b > c ? 1 : 0;
 }, "JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "isCumulativeType", 
- function (a) {
-return (this.parent != null && this.parent.isAlkeneAtom2 && ((this.parent.alkeneParent.sphere + this.parent.sphere) % 2) == (a == -2 ? 1 : 2));
-}, "~N");
+Clazz.defineMethod (c$, "isEvenCumulene", 
+ function () {
+return (this.parent != null && this.parent.isAlkeneAtom2 && ((this.parent.alkeneParent.sphere + this.parent.sphere) % 2) == 1);
+});
 Clazz.defineMethod (c$, "getEZaux", 
  function () {
 if (this.auxEZ == -1 && (this.auxEZ = this.alkeneParent.auxEZ) == -1) {
-this.auxEZ = this.getEneWinnerChirality (this.alkeneParent, this.alkeneParent.nextSP2, this.parent, this, 4, false);
+this.auxEZ = this.getEneWinnerChirality (this.alkeneParent, this, 4, false);
 if (this.auxEZ == 0) this.auxEZ = 24;
 }this.alkeneParent.auxEZ = this.auxEZ;
 if (JU.Logger.debugging) JU.Logger.info ("getZaux " + this.alkeneParent + " " + this.auxEZ);
 return this.auxEZ;
 });
 Clazz.defineMethod (c$, "getEneWinnerChirality", 
- function (a, b, c, d, e, f) {
-var g = this.getEneEndWinner (a, b, e);
-var h = (g == null || g.atom == null ? null : this.getEneEndWinner (d, c, e));
-return this.b$["JS.CIPChirality"].getEneChirality (g, a, d, h, f, false);
-}, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~N,~B");
+ function (a, b, c, d) {
+var e = this.getEneEndWinner (a, a.nextSP2, c);
+var f = (e == null || e.atom == null ? null : this.getEneEndWinner (b, b.parent, c));
+return this.b$["JS.CIPChirality"].getEneChirality (e, a, b, f, d, false);
+}, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~N,~B");
+Clazz.defineMethod (c$, "getEneEndWinner", 
+ function (a, b, c) {
+var d = a.clone ();
+d.addReturnPath (b, d);
+var e = null;
+for (var f = 1; f <= c; f++) if ((e = d.getTopSorted (f)) != null) break;
+
+return (e == null || e.atom == null ? null : e);
+}, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~N");
 Clazz.defineMethod (c$, "getReturnPath", 
  function (a) {
 var b =  new JU.Lst ();
@@ -934,56 +923,64 @@ d = g;
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
 Clazz.defineMethod (c$, "checkRule4And5", 
  function (a, b) {
-return (this.rule4List[a] == null && this.rule4List[b] == null ? 0 : this.rule4List[b] == null ? -1 : this.rule4List[a] == null ? 1 : this.compareRootMataPair (a, b));
+return (this.rule4List[a] == null && this.rule4List[b] == null ? 0 : this.rule4List[b] == null ? -1 : this.rule4List[a] == null ? 1 : this.compareMataPair (a, b));
 }, "~N,~N");
-Clazz.defineMethod (c$, "compareRootMataPair", 
+Clazz.defineMethod (c$, "compareMataPair", 
  function (a, b) {
-var c = (this.b$["JS.CIPChirality"].currentRule == 7);
-var d = this.rule4List[a].substring (1);
-var e = this.rule4List[b].substring (1);
-var f = false;
+var c = this.rule4List[a].substring (1);
+var d = this.rule4List[b].substring (1);
+if (this.b$["JS.CIPChirality"].currentRule == 7) {
+c = JU.PT.rep (c, "~", "");
+d = JU.PT.rep (d, "~", "");
+} else {
+var e = false;
+var f = (this.b$["JS.CIPChirality"].currentRule == 8);
 if (this.atoms[a].nextChiralBranch != null) {
-var g = this.atoms[a].getMataList (this.getFirstRef (d), c);
-f = (g.indexOf ("|") >= 0);
-d = (f ? g : d + g);
+var g = this.atoms[a].getMataList (this.getFirstRef (c), f);
+e = (g.indexOf ("|") >= 0);
+c = (e ? g : c + g);
 }if (this.atoms[b].nextChiralBranch != null) {
-var g = this.atoms[b].getMataList (this.getFirstRef (e), c);
-f = new Boolean (f | (g.indexOf ("|") >= 0)).valueOf ();
-e = (g.indexOf ("|") < 0 ? e + g : g);
-}if (JU.Logger.debugging) JU.Logger.info (this.dots () + this + " comparing " + this.atoms[a] + " " + d + " to " + this.atoms[b] + " " + e);
-if (c || !f && d.length != e.length) {
-return this.b$["JS.CIPChirality"].sign (d.compareTo (e));
-}if (f) {
-var g = JU.PT.split (d, "|");
-var h = JU.PT.split (e, "|");
+var g = this.atoms[b].getMataList (this.getFirstRef (d), f);
+e = new Boolean (e | (g.indexOf ("|") >= 0)).valueOf ();
+d = (g.indexOf ("|") < 0 ? d + g : g);
+}if (JU.Logger.debugging) JU.Logger.info (this.dots () + this + " comparing " + this.atoms[a] + " " + c + " to " + this.atoms[b] + " " + d);
+if (f || !e && c.length != d.length) {
+return this.sign (c.compareTo (d));
+}c = this.cleanRule4Str (c);
+d = this.cleanRule4Str (d);
+if (e) {
+var g = JU.PT.split (c, "|");
+var h = JU.PT.split (d, "|");
 var i = 2147483647;
 var j = 0;
-d = g[0];
-e = h[0];
+c = g[0];
+d = h[0];
 for (var k = g.length; --k >= 0; ) {
 for (var l = h.length; --l >= 0; ) {
 var m = this.compareRule4PairStr (g[k], h[l], true);
 j += m;
 if (m != 0 && Math.abs (m) <= i) {
 i = Math.abs (m);
-d = g[k];
-e = h[l];
+c = g[k];
+d = h[l];
 }}
 }
 if (j == 0) return 0;
-}d = JU.PT.rep (d, "~", "");
-e = JU.PT.rep (e, "~", "");
-if (d.length == 1 && "RS".indexOf (d) < 0) {
-var g = this.checkEnantiomer (d, e, 0, d.length, " rs");
-switch (g) {
+}}if (c.length == 1 && "RS".indexOf (c) < 0) {
+var e = this.checkEnantiomer (c, d, 0, c.length, " rs");
+switch (e) {
 case -1:
 case 1:
 this.canBePseudo = false;
 this.doCheckPseudo = true;
-return g;
+return e;
 }
-}return this.compareRule4PairStr (d, e, false);
+}return this.compareRule4PairStr (c, d, false);
 }, "~N,~N");
+Clazz.defineMethod (c$, "cleanRule4Str", 
+ function (a) {
+return (a.length > 1 ? JU.PT.replaceAllCharacters (a, "sr~", "") : a);
+}, "~S");
 Clazz.defineMethod (c$, "getFirstRef", 
  function (a) {
 for (var b = 0, c = a.length; b < c; b++) {
@@ -1049,7 +1046,7 @@ return k;
 }, "~A,~S,~B");
 Clazz.defineMethod (c$, "compareRule4PairStr", 
  function (a, b, c) {
-if (JU.Logger.debugging) JU.Logger.info (this.dots () + this + " Rule 4b comparing " + a + " " + b);
+if (JU.Logger.debugging) JU.Logger.info (this.dots () + this.myPath + " Rule 4b comparing " + a + " " + b);
 this.doCheckPseudo = false;
 var d = a.length;
 if (d == 0 || d != b.length) return 0;
@@ -1117,35 +1114,60 @@ case 1:
 break;
 case 2:
 if (a != null) {
-l = (this.compareRule4aEnantiomers (this.rule4List[h[0]], this.rule4List[h[1]]));
+l = (this.compareRule4aIsomers (h[0], h[1]));
 switch (l) {
-case 2147483647:
+case 0:
 f = true;
-e = "";
+e = "~";
+d = "";
 break;
 case -2147483648:
 e = "";
 f = true;
 l = 0;
 break;
-case 0:
-f = true;
-e = "~";
-d = "";
-break;
+case -2:
+case 2:
+l -= this.sign (l);
+d = "r";
 case -1:
 case 1:
 f = true;
 g = d.indexOf ("r") >= 0;
-if (g) System.out.println ("testingrs");
 d = "";
 break;
 }
 }break;
 case 3:
-case 4:
+var m = 0;
+var n = 0;
+var o = 0;
+for (var p = 0; p < 2; p++) {
+for (var q = p + 1; q < 3; q++) {
+o = (this.compareRule4aIsomers (h[p], h[q]));
+switch (o) {
+case -1:
+case 1:
+if (l == 0) {
+l = o;
+m = p;
+n = q;
+continue;
+}p = q = 3;
+l = 0;
+break;
+default:
+break;
+}
+}
+}
+if (l != 0) {
+h[0] = h[m];
+h[1] = h[n];
+}case 4:
 e = "";
 f = true;
+break;
 }
 if (f) {
 d = "";
@@ -1153,10 +1175,10 @@ if (b != null) b[0] = this;
 }if (!f || l == -1 || l == 1) {
 if (this.isAlkene) {
 if (!f && this.alkeneChild != null) {
-var m = (b != null && b[0] === this.alkeneChild);
-var n = (((this.alkeneChild.sphere - this.sphere) % 2) == 0);
-if (n || this.auxEZ == 24 && this.alkeneChild.bondCount >= 2 && !this.isAromatic) {
-c = this.getEneWinnerChirality (this, this.nextSP2, this.alkeneChild.parent, this.alkeneChild, 7, n);
+var q = (b != null && b[0] === this.alkeneChild);
+var r = (((this.alkeneChild.sphere - this.sphere) % 2) == 0);
+if (r || this.auxEZ == 24 && this.alkeneChild.bondCount >= 2 && !this.isKekuleAmbiguous) {
+c = this.getEneWinnerChirality (this, this.alkeneChild, 8, r);
 switch (c) {
 case 33:
 c = 1;
@@ -1179,7 +1201,7 @@ if (c != 0) {
 this.auxChirality = e;
 this.addMataRef (this.sphere, this.priority, c);
 d = "";
-if (m) {
+if (q) {
 this.nextChiralBranch = this.alkeneChild;
 b[0] = this;
 }}}}} else if (a != null && (this.bondCount == 4 && this.nPriorities >= 3 - Math.abs (l) || this.isTrigonalPyramidal && this.nPriorities >= 2 - Math.abs (l))) {
@@ -1195,39 +1217,26 @@ break;
 if (g) e = e.toUpperCase ();
 this.auxChirality = e;
 d = "";
-if (b != null) b[0] = null;
 } else {
-var m = this.clone ();
-if (m.set ()) {
-m.addReturnPath (null, this);
-m.sortByRule (1);
-c = m.checkHandedness ();
+var q = this.clone ();
+if (q.set ()) {
+q.addReturnPath (null, this);
+q.sortByRule (1);
+c = q.checkHandedness ();
 e = (c == 1 ? "R" : c == 2 ? "S" : "~");
 a.addMataRef (this.sphere, this.priority, c);
 }}}}}e += d;
 if (JU.Logger.debugging && !e.equals ("~")) JU.Logger.info ("creating aux " + this.myPath + e);
 return e;
 }, "JS.CIPChirality.CIPAtom,~A");
-Clazz.defineMethod (c$, "getEneEndWinner", 
- function (a, b, c) {
-var d = a.clone ();
-d.addReturnPath (b, d);
-var e = this.b$["JS.CIPChirality"].root.canBePseudo;
-var f = null;
-for (var g = 1; g <= c; g++) {
-d.sortByRule (g);
-f = d.getTopAtom ();
-if (f != null && f.atom != null) break;
-}
-this.b$["JS.CIPChirality"].root.canBePseudo = e;
-return f;
-}, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom,~N");
 Clazz.defineMethod (c$, "sortByRule", 
  function (a) {
-var b = this.b$["JS.CIPChirality"].currentRule;
+var b = this.b$["JS.CIPChirality"].root.canBePseudo;
+var c = this.b$["JS.CIPChirality"].currentRule;
 this.b$["JS.CIPChirality"].currentRule = a;
 this.sortSubstituents ();
-this.b$["JS.CIPChirality"].currentRule = b;
+this.b$["JS.CIPChirality"].currentRule = c;
+this.b$["JS.CIPChirality"].root.canBePseudo = b;
 }, "~N");
 Clazz.defineMethod (c$, "isChiralSequence", 
  function (a) {
@@ -1244,15 +1253,29 @@ this.rule4Count[0] = d;
 this.rule4Count[1] = this.rule4Count[2] = 0;
 }this.rule4Count[c]++;
 }}, "~N,~N,~N");
-Clazz.defineMethod (c$, "compareRule4aEnantiomers", 
+Clazz.defineMethod (c$, "compareRule4aIsomers", 
  function (a, b) {
-if (a.charAt (0) != b.charAt (0)) return -2147483648;
-var c = a.length;
-if (c != b.length) return -2147483648;
-if (a.equals (b)) return 0;
-var d = (a.indexOf ("R") < 0 && a.indexOf ("S") < 0 ? "~rs" : "~RS");
-return this.checkEnantiomer (a, b, 1, c, d);
-}, "~S,~S");
+var c = this.rule4List[a];
+var d = this.rule4List[b];
+if (c.charAt (0) != d.charAt (0)) return -2147483648;
+var e = c.length;
+if (e != d.length) return -2147483648;
+if (c.equals (d)) return 0;
+var f = (c.indexOf ("R") >= 0 || c.indexOf ("S") >= 0);
+var g = (f ? "~RS" : "~rs");
+if (f) {
+c = JU.PT.replaceAllCharacters (c, "rs", "~");
+d = JU.PT.replaceAllCharacters (d, "rs", "~");
+}var h = this.checkEnantiomer (c, d, 1, e, g);
+if (h == -3) {
+switch (this.compareMataPair (a, b)) {
+case -1:
+return -2;
+case 1:
+return 2;
+}
+}return h;
+}, "~N,~N");
 Clazz.defineMethod (c$, "checkEnantiomer", 
  function (a, b, c, d, e) {
 var f = 0;
@@ -1260,8 +1283,9 @@ for (var g = c; g < d; g++) {
 var h = e.indexOf (a.charAt (g));
 var i = h + e.indexOf (b.charAt (g));
 if (i == 0) continue;
-if (i != 3) return 2147483647;
-if (f == 0) f = (h == 1 ? -1 : 1);
+if (i != 3) {
+return -3;
+}if (f == 0) f = (h == 1 ? -1 : 1);
 }
 return f;
 }, "~S,~S,~N,~N,~S");
@@ -1292,11 +1316,15 @@ this.parent = a;
 return;
 }
 }, "JS.CIPChirality.CIPAtom,JS.CIPChirality.CIPAtom");
-Clazz.defineMethod (c$, "getTopAtom", 
- function () {
-var a = (this.atoms[0].isDuplicate ? 1 : 0);
-return this.priorities[a] == this.priorities[a + 1] ? null : this.priorities[a] < this.priorities[a + 1] ? this.atoms[a] : this.atoms[a + 1];
-});
+Clazz.defineMethod (c$, "getTopSorted", 
+ function (a) {
+this.sortByRule (a);
+for (var b = 0; b < 4; b++) {
+var c = this.atoms[b];
+if (!c.sp2Duplicate) return this.priorities[b] == this.priorities[b + 1] ? null : this.atoms[b];
+}
+return null;
+}, "~N");
 Clazz.defineMethod (c$, "checkRules4a", 
  function (a, b) {
 if (this.isTerminal || this.isDuplicate) return 0;
@@ -1309,10 +1337,15 @@ function () {
 var a = this.atoms[0].atom.getXYZ ();
 var b = this.atoms[1].atom.getXYZ ();
 var c = this.atoms[2].atom.getXYZ ();
-var d = (this.lonePair == null ? this.atoms[3].atom.getXYZ () : this.lonePair);
-var e = JU.Measure.getNormalThroughPoints (a, b, c, this.b$["JS.CIPChirality"].vNorm, this.b$["JS.CIPChirality"].vTemp);
-return (JU.Measure.distanceToPlaneV (this.b$["JS.CIPChirality"].vNorm, e, d) > 0 ? 1 : 2);
+JU.Measure.getNormalThroughPoints (a, b, c, this.b$["JS.CIPChirality"].vNorm, this.b$["JS.CIPChirality"].vTemp);
+this.b$["JS.CIPChirality"].vTemp.setT (this.atom.getXYZ ());
+this.b$["JS.CIPChirality"].vTemp.sub (a);
+return (this.b$["JS.CIPChirality"].vTemp.dot (this.b$["JS.CIPChirality"].vNorm) > 0 ? 1 : 2);
 });
+Clazz.defineMethod (c$, "sign", 
+function (a) {
+return (a < 0 ? -1 : a > 0 ? 1 : 0);
+}, "~N");
 Clazz.defineMethod (c$, "clone", 
 function () {
 var a = null;
@@ -1328,14 +1361,16 @@ a.id = this.b$["JS.CIPChirality"].ptID++;
 a.atoms =  new Array (4);
 a.priorities =  Clazz.newIntArray (4, 0);
 a.htPathPoints = this.htPathPoints;
+a.doCheckPseudo = false;
 for (var b = 0; b < 4; b++) {
 if (this.atoms[b] != null) {
 a.atoms[b] = this.atoms[b];
 }}
+a.ties = null;
 if (JU.Logger.debugging) JU.Logger.info ("cloning " + this + " as " + a);
 return a;
 });
-Clazz.defineMethod (c$, "toString", 
+Clazz.overrideMethod (c$, "toString", 
 function () {
 return (this.atom == null ? "<null>" : "[" + this.b$["JS.CIPChirality"].currentRule + "." + this.sphere + "," + this.rootDistance + "." + this.id + "." + this.atom.getAtomName () + (this.isDuplicate ? "*" : "") + "]");
 });
@@ -1346,10 +1381,11 @@ Clazz.defineStatics (c$,
 "TIED", 0,
 "B_WINS", 1,
 "A_WINS", -1,
-"DIASTEREOMERIC", 2147483647,
+"DIASTEREOMERIC", -3,
+"DIASTEREOMERIC_A_WINS", -2,
+"DIASTEREOMERIC_B_WINS", 2,
 "IGNORE", -2147483648,
 "NOT_RELEVANT", -2147483648,
-"STEREO_SAME", 2147483647,
 "STEREO_UNDETERMINED", -1,
 "STEREO_RS", -1,
 "STEREO_EZ", -2,
@@ -1367,10 +1403,11 @@ Clazz.defineStatics (c$,
 "RULE_2", 3,
 "RULE_3", 4,
 "RULE_4a", 5,
-"RULE_4bc", 6,
-"RULE_5", 7,
-"ruleNames",  Clazz.newArray (-1, ["", "1a", "1b", "2", "3", "4a", "4bc", "5"]),
+"RULE_4b", 6,
+"RULE_4c", 7,
+"RULE_5", 8,
+"ruleNames",  Clazz.newArray (-1, ["", "1a", "1b", "2", "3", "4a", "4b", "4c", "5"]),
 "TRIGONALITY_MIN", 0.2,
-"MAX_PATH", 30,
+"MAX_PATH", 50,
 "SMALL_RING_MAX", 7);
 });
