@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (null, "JS.SmilesAromatic", ["java.util.Hashtable", "JU.BS", "$.Lst", "$.V3", "JS.SmilesRing", "$.SmilesRingSet", "$.SmilesSearch", "JU.BSUtil", "$.Logger"], function () {
+Clazz.load (null, "JS.SmilesAromatic", ["java.util.Hashtable", "JU.BS", "$.Lst", "$.Measure", "$.V3", "JS.SmilesRing", "$.SmilesRingSet", "JU.BSUtil", "$.Logger"], function () {
 c$ = Clazz.declareType (JS, "SmilesAromatic");
 c$.setAromatic = Clazz.defineMethod (c$, "setAromatic", 
 function (n, jmolAtoms, bsSelected, vR, bsAromatic, strictness, isOpenSMILES, justCheckBonding, checkExplicit, v, vOK, lstSP2, eCounts, doTestAromatic) {
@@ -65,9 +65,8 @@ for (var i = bs.nextSetBit (0); i >= 0; i = bs.nextSetBit (i + 1)) if (atoms[i].
 
 }if (cutoff == 3.4028235E38) return true;
 if (cutoff <= 0) cutoff = 0.01;
-var vTemp =  new JU.V3 ();
-var vA =  new JU.V3 ();
-var vB =  new JU.V3 ();
+var vNorm = null;
+var vTemp = null;
 var vMean = null;
 var nPoints = bs.cardinality ();
 var vNorms =  new Array (nPoints * 2);
@@ -92,11 +91,14 @@ r1 = iAtom;
 } else {
 r2 = iAtom;
 }}
-if (vMean == null) vMean =  new JU.V3 ();
-for (var k = 0, j = i; k < 2; k++) {
-JS.SmilesSearch.getNormalThroughPoints (atoms[r1], atoms[j], atoms[r2], vTemp, vA, vB);
-if (!JS.SmilesAromatic.addNormal (vTemp, vMean, maxDev)) return false;
-vNorms[nNorms++] = JU.V3.newV (vTemp);
+if (vMean == null) {
+vMean =  new JU.V3 ();
+vNorm =  new JU.V3 ();
+vTemp =  new JU.V3 ();
+}for (var k = 0, j = i; k < 2; k++) {
+JU.Measure.getNormalThroughPoints (atoms[r1], atoms[j], atoms[r2], vNorm, vTemp);
+if (!JS.SmilesAromatic.addNormal (vNorm, vMean, maxDev)) return false;
+vNorms[nNorms++] = JU.V3.newV (vNorm);
 if ((j = iSub) < 0) break;
 }
 }
