@@ -493,8 +493,20 @@ return cip.getBondChirality (bond);
 Clazz.overrideMethod (c$, "calculateCIPChiralityForAtoms", 
 function (vwr, bsAtoms) {
 var cip = this.getCIPChirality (vwr);
-var bsAtropisomer = vwr.getAtomBitSet ("smarts('a-a')");
-cip.getChiralityForAtoms (vwr.ms.at, bsAtoms, bsAtropisomer);
+var bsAtropisomer = null;
+var bsHelixM = null;
+var bsHelixP = null;
+try {
+bsAtropisomer = vwr.getSmartsMatch ("a-a", bsAtoms);
+bsHelixM = vwr.getSmartsMatch ("A{a}(.t:-10,-40)a(.t:-10,-40)aaa", bsAtoms);
+bsHelixP = vwr.getSmartsMatch ("A{a}(.t:10,40)a(.t:10,40)aaa", bsAtoms);
+} catch (e) {
+if (Clazz.exceptionOf (e, Exception)) {
+} else {
+throw e;
+}
+}
+cip.getChiralityForAtoms (vwr.ms.at, bsAtoms, bsAtropisomer, bsHelixM, bsHelixP);
 }, "JV.Viewer,JU.BS");
 Clazz.defineMethod (c$, "getCIPChirality", 
  function (vwr) {
