@@ -138,6 +138,13 @@ throw e;
 }
 return order;
 }, "~S");
+Clazz.defineMethod (c$, "setCIPChirality", 
+function (c) {
+}, "~N");
+Clazz.defineMethod (c$, "getCIPChirality", 
+function (doCalculate) {
+return "";
+}, "~B");
 Clazz.pu$h(self.c$);
 c$ = Clazz.decorateAsClass (function () {
 this.code = 0;
@@ -192,6 +199,11 @@ Clazz.defineStatics (c$,
 "TYPE_ATROPISOMER", 0x10001,
 "TYPE_ATROPISOMER_REV", 0x10002,
 "ATROPISOMER_SHIFT", 11,
+"BOND_CIP_STEREO_MASK", 0xC0000,
+"BOND_CIP_STEREO_UNK", 0xC0000,
+"BOND_CIP_STEREO_E", 0x80000,
+"BOND_CIP_STEREO_Z", 0x40000,
+"BOND_CIP_STEREO_SHIFT", 18,
 "BOND_STEREO_MASK", 0x400,
 "BOND_STEREO_NEAR", 0x401,
 "BOND_STEREO_FAR", 0x411,
