@@ -155,7 +155,7 @@ null,1073741994,0,-1);null==k&&(k=this.vwr.getSymTemp());k.toFromPrimitive(!0,0=
 2*f.y,0),JU.P3.new3(0,0,2*f.z)]);f=null;b.iToken=a;break;case 1073742176:12!=this.tokAt(++a)&&this.invArg();j=A(-1,[this.getToken(a).value]);break;case 11:case 12:j=this.getToken(a).value;break;case 12289:switch(this.tokAt(++a)){case 12290:case 10:case 1073742325:f=this.vwr.ms.getAtomSetCenter(this.atomExpressionAt(a));this.vwr.toFractional(f,!0);a=b.iToken;break;default:if(b.isCenterParameter(a)){f=this.centerParameter(a);a=b.iToken;break}this.invArg()}f.x-=0.5;f.y-=0.5;f.z-=0.5;break;case 12290:case 10:case 1073742325:a=
 this.atomExpressionAt(a).nextSetBit(0);this.chk||(this.vwr.am.cai=a);if(0>a)return;a=b.iToken;break;case 1073742066:d=!0;case 1073742114:f=b.getPointOrPlane(++a,!1,!0,!1,!0,3,3);f=JU.P4.new4(f.x,f.y,f.z,d?1:0);a=b.iToken;break;case 3:case 2:if(111>this.floatParameter(a)){a--;break}c=this.intParameter(a);break;default:b.isArrayParameter(a)?(h=b.getPointArray(a,4,!1),a=b.iToken):this.slen>a+1?(f=b.getPointOrPlane(a,!1,!0,!1,!0,3,3),a=b.iToken):a--}d=b.getSetAxesTypeMad10(++a);b.checkLast(b.iToken);
 this.chk||2147483647==d||(2147483647==d&&(this.vwr.am.cai=-1),null==h&&null!=j&&(h=this.vwr.getV0abc(j)),2147483647!=c?this.vwr.ms.setUnitCellOffset(this.vwr.getCurrentUnitCell(),null,c):null!=g?this.vwr.setCurrentCage(g):(p||null!=h)&&b.setCurrentCagePts(h,l),b.setObjectMad10(33,"unitCell",d),null!=f&&this.vwr.ms.setUnitCellOffset(this.vwr.getCurrentUnitCell(),f,0),null!=e&&this.setShapeProperty(33,"tickInfo",e))},"~N");l(c$,"assign",function(){var a=this.tokAt(1),b=this.atomExpressionAt(2).nextSetBit(0),
-c=-1,d=null;if(!(0>b)){4106==a?c=this.atomExpressionAt(++this.e.iToken).nextSetBit(0):d=this.paramAsStr(++this.e.iToken);var f=++this.e.iToken<this.slen?this.centerParameter(this.e.iToken):null;if(!this.chk)switch(a){case 1140850689:this.e.clearDefinedVariableAtomSets();this.assignAtom(b,f,d);break;case 1677721602:this.assignBond(b,(d+"p").charAt(0));break;case 4106:this.assignConnect(b,c)}}});l(c$,"assignAtom",function(a,b,c){c.equals("X")&&this.vwr.setRotateBondIndex(-1);if(this.vwr.ms.at[a].mi==
+c=-1,d=null;if(!(0>b)){4106==a?c=this.atomExpressionAt(++this.e.iToken).nextSetBit(0):d=this.paramAsStr(++this.e.iToken);var f=++this.e.iToken<this.slen?this.centerParameter(this.e.iToken):null;if(!this.chk)switch(this.vwr.pushState(),a){case 1140850689:this.e.clearDefinedVariableAtomSets();this.assignAtom(b,f,d);break;case 1677721602:this.assignBond(b,(d+"p").charAt(0));break;case 4106:this.assignConnect(b,c)}}});l(c$,"assignAtom",function(a,b,c){c.equals("X")&&this.vwr.setRotateBondIndex(-1);if(this.vwr.ms.at[a].mi==
 this.vwr.ms.mc-1){this.vwr.clearModelDependentObjects();var d=this.vwr.ms.ac;if(null==b)this.vwr.sm.modifySend(a,this.vwr.ms.at[a].mi,1,this.e.fullCommand),this.vwr.ms.assignAtom(a,c,!0),JU.PT.isOneOf(c,";Mi;Pl;X;")||this.vwr.ms.setAtomNamesAndNumbers(a,-d,null),this.vwr.sm.modifySend(a,this.vwr.ms.at[a].mi,-1,"OK"),this.vwr.refresh(3,"assignAtom");else{var f=this.vwr.ms.at[a],e=JU.BSUtil.newAndSetBit(a);b=A(-1,[b]);var g=new JU.Lst;g.addLast(f);f=f.mi;this.vwr.sm.modifySend(a,f,3,this.e.fullCommand);
 try{e=this.vwr.addHydrogensInline(e,g,b),a=e.nextSetBit(0),this.vwr.ms.assignAtom(a,c,!1)}catch(h){if(!M(h,Exception))throw h;}this.vwr.ms.setAtomNamesAndNumbers(a,-d,null);this.vwr.sm.modifySend(a,f,-3,"OK")}}},"~N,JU.P3,~S");l(c$,"assignBond",function(a,b){var c=-1;try{c=this.vwr.ms.bo[a].atom1.mi;this.vwr.sm.modifySend(a,c,2,this.e.fullCommand);var d=this.vwr.ms.assignBond(a,b);null==d||"0"==b?this.vwr.refresh(3,"setBondOrder"):this.vwr.addHydrogens(d,!1,!0);this.vwr.sm.modifySend(a,c,-2,""+b)}catch(f){if(M(f,
 Exception))JU.Logger.error("assignBond failed"),this.vwr.sm.modifySend(a,c,-2,"ERROR "+f);else throw f;}},"~N,~S");l(c$,"assignConnect",function(a,b){this.vwr.clearModelDependentObjects();var c=JU.AU.newFloat2(1);c[0]=L(-1,[a,b]);var d=this.vwr.ms.at[a].mi;this.vwr.sm.modifySend(a,d,2,this.e.fullCommand);this.vwr.ms.connect(c);this.vwr.ms.assignAtom(a,".",!0);this.vwr.ms.assignAtom(b,".",!0);this.vwr.sm.modifySend(a,d,-2,"OK");this.vwr.refresh(3,"assignConnect")},"~N,~N");l(c$,"getContext",function(a){for(var b=
