@@ -85,29 +85,29 @@ if(7==g.tok){for(var g=JS.SV.strListValue(g),f=Array(g.length),h=g.length;0<=--h
 a.length?c.equalsIgnoreCase("JSON")&&d.addXObj(this.vwr.parseJSON(JS.SV.sValue(a[1]))):d.addXObj(this.vwr.evaluateExpressionAsVariable(c));case 134222850:a=2==a.length?JS.SV.sValue(a[1]):".";a.equals(".")||e.append(this.vwr.jsEval(a+"\u0001"+c));(a.equals(".")||a.equals("*"))&&this.e.runScriptBuffer(c,e,!0);break;case 134222350:this.e.runScriptBuffer("show "+c,e,!0);break;case 134238732:return d.addX(this.vwr.jsEvalSV(c))}var c=e.toString(),g;return Float.isNaN(g=JU.PT.parseFloatStrict(c))?d.addXStr(c):
 0<=c.indexOf(".")?d.addXFloat(g):d.addXInt(JU.PT.parseInt(c))},"JS.ScriptMathProcessor,~A,~N");l(c$,"evaluateSort",function(d,a,b){if(1<a.length)return!1;if(1275068444==b){if(1==a.length&&4==a[0].tok)return d.addX(d.getX().sortMapArray(a[0].asString()));var c=0==a.length?0:a[0].asInt();return d.addX(d.getX().sortOrReverse(c))}b=d.getX();a=0==a.length?null:a[0];if(4==b.tok){var c=0,e=JS.SV.sValue(b);if(null==a)return d.addXInt(0);a=JS.SV.sValue(a);for(b=0;b<e.length;b++){b=e.indexOf(a,b);if(0>b)break;
 c++}return d.addXInt(c)}var c=new JU.Lst,g=e=null,f=JS.SV.getVariable(b.value).sortOrReverse(0).getList();if(null==f)return null==a?d.addXStr(""):d.addXInt(0);b=0;for(var h=f.size();b<=h;b++){var k=b==h?null:f.get(b);if(!(null!=a&&null!=k&&!JS.SV.areEqual(k,a)))if(JS.SV.areEqual(k,e))g.intValue++;else{if(null!=e){var j=new JU.Lst;j.addLast(e);j.addLast(g);c.addLast(JS.SV.getVariableList(j))}g=JS.SV.newI(1);e=k}}return null==a?d.addX(JS.SV.getVariableList(c)):c.isEmpty()?d.addXInt(0):d.addX(c.get(0).getList().get(1))},
-"JS.ScriptMathProcessor,~A,~N");l(c$,"evaluateString",function(d,a,b){var c=d.getX(),e=0<b.length?JS.SV.sValue(b[0]):1275068932==a?"":"\n";switch(b.length){case 0:case 1:break;case 2:if(7==c.tok)break;if(1275069447==a){c=JS.SV.getVariable(JU.PT.split(JU.PT.rep(c.value,"\n\r","\n").$replace("\r","\n"),"\n"));break}default:return!1}if(7==c.tok&&1275068932!=a&&(1275069447!=a||2==b.length))return d.addX(c),this.evaluateList(d,a,b);b=1275069447==a&&10==c.tok||1275068932==a&&7==c.tok?null:JS.SV.sValue(c);
-switch(a){case 1275069447:if(10==c.tok){e=c.value;c=this.vwr.ms.mc;b=new JU.Lst;for(a=0;a<c;a++){var g=this.vwr.getModelUndeletedAtomsBitSet(a);g.and(e);b.addLast(JS.SV.getVariable(g))}return d.addXList(b)}return d.addXAS(JU.PT.split(b,e));case 1275069446:return 0<b.length&&"\n"==b.charAt(b.length-1)&&(b=b.substring(0,b.length-1)),d.addXStr(JU.PT.rep(b,"\n",e));case 1275068932:if(null!=b)return d.addXStr(JU.PT.trim(b,e));c=JS.SV.strListValue(c);for(a=c.length;0<=--a;)c[a]=JU.PT.trim(c[a],e);return d.addXAS(c)}return d.addXStr("")},
-"JS.ScriptMathProcessor,~N,~A");l(c$,"evaluateSubstructure",function(d,a,b,c){if(0==a.length||c&&1<a.length)return!1;var e=new JU.BS,g=JS.SV.sValue(a[0]);if(0<g.length)try{var f=c?d.getX().value:2==a.length&&10==a[1].tok?a[1].value:null,e=this.vwr.getSmilesMatcher().getSubstructureSet(g,this.vwr.ms.at,this.vwr.ms.ac,f,134218757==b?1:2)}catch(h){if(C(h,Exception))this.e.evalError(h.getMessage(),null);else throw h;}return d.addXBs(e)},"JS.ScriptMathProcessor,~A,~N,~B");l(c$,"evaluateSymop",function(d,
-a,b){b=b?d.getX():null;if(null!=b&&10!=b.tok)return!1;b=null==b?null:b.value;null==b&&1==this.vwr.ms.mc&&(b=this.vwr.getModelUndeletedAtomsBitSet(0));var c=a.length;if(0==c){if(b.isEmpty())return!1;a=JU.PT.split(JU.PT.trim(this.vwr.getSymTemp().getSpaceGroupInfo(this.vwr.ms,null,this.vwr.ms.at[b.nextSetBit(0)].mi).get("symmetryInfo"),"\n"),"\n");b=new JU.Lst;for(var e=0,g=a.length;e<g;e++)b.addLast(JU.PT.split(a[e],"\t"));return d.addXList(b)}var e=null,g=-2147483648,f=0;switch(a[0].tok){case 4:e=
-JS.SV.sValue(a[0]);f++;break;case 12:e=a[0].escape();f++;break;case 2:g=a[0].asInt(),f++}null==b&&(f<c&&10==a[f].tok&&(b=new JU.BS).or(a[f].value),f+1<c&&10==a[f+1].tok&&(null==b?b=new JU.BS:b).or(a[f+1].value));var h=null,k=null;null!=(h=c>f?d.ptValue(a[f],b):null)&&f++;null!=(k=c>f?d.ptValue(a[f],b):null)&&f++;var j=null!=k&&a.length>f&&-2147483648==g&&2==a[f].tok?a[f].intValue:0;0<j&&f++;-2147483648==g&&(g=0);c=c==f?null!=k?"all":null!=h?"point":"matrix":JS.SV.sValue(a[f++]).toLowerCase();return null!=
-b&&!b.isEmpty()&&f==a.length&&d.addXObj(this.vwr.getSymTemp().getSymmetryInfoAtom(this.vwr.ms,b.nextSetBit(0),e,g,h,k,c,0,0,j))},"JS.ScriptMathProcessor,~A,~B");l(c$,"evaluateTensor",function(d,a){var b=d.getX();if(2<a.length||10!=b.tok)return!1;var b=b.value,c=0==a.length?null:JS.SV.sValue(a[0]).toLowerCase(),e=this.vwr.getNMRCalculation();if("unique".equals(c))return d.addXBs(e.getUniqueTensorSet(b));var g=2>a.length?null:JS.SV.sValue(a[1]).toLowerCase();return d.addXList(e.getTensorInfo(c,g,b))},
-"JS.ScriptMathProcessor,~A");l(c$,"evaluateUserFunction",function(d,a,b,c,e){var g=null;if(e)switch(g=d.getX(),g.tok){case 10:break;case 6:if(0<b.length)return!1;g=g.getMap().get(a);return null==g?d.addXStr(""):d.addX(g);default:return!1}a=a.toLowerCase();d.wasX=!1;for(var f=new JU.Lst,h=0;h<b.length;h++)f.addLast(b[h]);if(e)return d.addXObj(this.e.getBitsetProperty(g.value,c,null,null,g.value,x(-1,[a,f]),!1,g.index,!1));a=this.e.getUserFunctionResult(a,f,null);return null==a?!1:d.addX(a)},"JS.ScriptMathProcessor,~S,~A,~N,~B");
-l(c$,"evaluateWithin",function(d,a){if(1>a.length||5<a.length)return!1;var b=a.length;if(1==b&&10==a[0].tok)return d.addX(a[0]);var c=0,e=a[0].value,g=""+e,f=a[0].tok;4==f&&(f=JS.T.getTokFromName(g));var h=this.vwr.ms,k=!1,j=!1,l=!1,n=!1,r=null;switch(f){case 1648363544:k=!0,e=null;case 3:case 2:n=!0;if(2>b||3==b&&7==a[1].tok&&7!=a[2].tok)return!1;c=k?100:JS.SV.fValue(a[0]);switch(f=a[1].tok){case 1073742335:case 1073742334:j=a[1].asBoolean();2<b&&JS.SV.sValue(a[2]).equalsIgnoreCase("unitcell")&&
-(f=1814695966);b=0;break;case 4:f=JS.SV.sValue(a[1]);if(f.startsWith("$"))return d.addXBs(this.getAtomsNearSurface(c,f.substring(1)));if(f.equalsIgnoreCase("group"))l=!0,f=1086324742;else if(f.equalsIgnoreCase("vanderwaals")||f.equalsIgnoreCase("vdw"))e=null,k=!0,f=1648363544;else if(f.equalsIgnoreCase("unitcell"))f=1814695966;else return!1}break;case 7:1==b&&(e=a[0].asString(),f=0);break;case 1073742328:return 3==b&&s(a[1].value,JU.BS)&&s(a[2].value,JU.BS)&&d.addXBs(this.vwr.getBranchBitSet(a[2].value.nextSetBit(0),
-a[1].value.nextSetBit(0),!0));case 134218757:case 1237320707:case 134218756:c=null;e=!0;switch(b){case 2:break;case 3:if(e=10==a[2].tok)c=a[2].value;break;default:e=!1}e||this.e.invArg();return d.addXObj(this.e.getSmilesExt().getSmilesMatches(JS.SV.sValue(a[1]),null,c,null,134218756==f?2:1,d.asBitSet,!1))}if(s(e,String)){if(0==f){f=1073742362;if(2<b)return!1;b=2}}else if(!n)return!1;switch(b){case 1:switch(f){case 136314895:case 2097184:case 1678381065:return d.addXBs(h.getAtoms(f,null));case 1073741863:return d.addXBs(h.getAtoms(f,
-""));case 1073742362:return d.addXBs(h.getAtoms(1086324744,g))}return!1;case 2:switch(f){case 1073742362:f=1086324744;break;case 1073741824:case 1086326786:case 1086326785:case 1073741863:case 1086324744:case 1111490587:case 1073742128:case 1073741925:case 1073742189:return d.addXBs(this.vwr.ms.getAtoms(f,JS.SV.sValue(a[a.length-1])))}break;case 3:switch(f){case 1073742335:case 1073742334:case 1086324742:case 1648363544:case 1814695966:case 134217750:case 134219265:case 1073742329:case 8:case 7:break;
-case 1086324744:g=JS.SV.sValue(a[2]);break;default:return!1}}var p=null,e=b=null,t=a.length-1;switch(a[t].tok){case 9:p=a[t].value;break;case 8:b=a[t].value;JS.SV.sValue(a[1]).equalsIgnoreCase("hkl")&&(p=this.e.getHklPlane(b));break;case 7:e=2==t&&7==a[1].tok?a[1].getList():null,b=2==t?JS.SV.ptValue(a[1]):1==t?JU.P3.new3(NaN,0,0):null}if(null!=p)return d.addXBs(h.getAtomsNearPlane(c,p));h=10==a[t].tok?a[t].value:null;if(0<t&&null==b&&null==e&&null==h)return!1;if(1814695966==f)return(null!=h||null!=
-b)&&d.addXObj(this.vwr.ms.getUnitCellPointsWithin(c,h,b,j));if(null!=b||null!=e){if(7==a[t].tok){g=a[t].getList();j=new JU.Lst;k=new J.bspt.Bspt(3,0);if(null!=b&&Float.isNaN(b.x)){e=Array(g.size());for(f=e.length;0<=--f;){l=JS.SV.ptValue(g.get(f));if(null==l)return!1;b=new JU.Point3fi;b.setT(l);b.i=f;e[f]=b;k.addTuple(b)}l=k.allocateCubeIterator();n=JU.BSUtil.newBitSet2(0,g.size());for(f=e.length;0<=--f;){l.initialize(b=e[f],c,!1);k=c*c;for(r=0;l.hasMoreElements();)g=l.nextElement(),n.get(g.i)&&(g.distanceSquared(b)<=
-k&&1<++r)&&n.clear(g.i)}for(f=n.nextSetBit(0);0<=f;f=n.nextSetBit(f+1))j.addLast(JU.P3.newP(e[f]));return d.addXList(j)}if(0==c){if(null==e){k=3.4028235E38;e=null;for(f=g.size();0<=--f;)j=JS.SV.ptValue(g.get(f)),c=j.distanceSquared(b),c<k&&(e=j,k=c);return null==e?d.addXStr(""):d.addXPt(e)}l=I(e.size(),0);for(f=l.length;0<=--f;){k=3.4028235E38;n=-1;b=JS.SV.ptValue(e.get(f));for(r=g.size();0<=--r;)j=JS.SV.ptValue(g.get(r)),c=j.distanceSquared(b),c<k&&(n=r,k=c);l[f]=n}return d.addXAI(l)}for(f=g.size();0<=
---f;)e=JS.SV.ptValue(g.get(f)),k.addTuple(e);l=k.allocateCubeIterator();l.initialize(b,c,!1);for(k=c*c;l.hasMoreElements();)g=l.nextElement(),g.distanceSquared(b)<=k&&j.addLast(g);l.release();return d.addXList(j)}return d.addXBs(this.vwr.getAtomsNearPt(c,b))}if(1086324744==f)return d.addXBs(this.vwr.ms.getSequenceBits(g,h,new JU.BS));null==h&&(h=new JU.BS);if(!n)return d.addXBs(this.vwr.ms.getAtoms(f,h));if(l)return d.addXBs(this.vwr.getGroupsWithin(A(c),h));k&&(r=new J.atomdata.RadiusData(null,10<
-c?c/100:c,10<c?J.atomdata.RadiusData.EnumType.FACTOR:J.atomdata.RadiusData.EnumType.OFFSET,J.c.VDW.AUTO),0>c&&(c=0));return d.addXBs(this.vwr.ms.getAtomsWithinRadius(c,h,j,r))},"JS.ScriptMathProcessor,~A");l(c$,"evaluateWrite",function(d,a){switch(a.length){case 0:return!1;case 1:if(!a[0].asString().toUpperCase().equals("PNGJ"))break;return d.addXMap(this.vwr.fm.getFileAsMap(null))}return d.addXStr(this.e.getCmdExt().dispatch(134221856,!0,a))},"JS.ScriptMathProcessor,~A");l(c$,"getAtomsNearSurface",
-function(d,a){var b=x(-1,[a,null,null]);if(this.e.getShapePropertyData(24,"getVertices",b))return this.getAtomsNearPts(d,b[1],b[2]);b[1]=Integer.$valueOf(0);b[2]=Integer.$valueOf(-1);return this.e.getShapePropertyData(22,"getCenter",b)?this.vwr.getAtomsNearPt(d,b[2]):new JU.BS},"~N,~S");l(c$,"getAtomsNearPts",function(d,a,b){var c=new JU.BS;if(0==a.length||null!=b&&b.isEmpty())return c;null==b&&(b=JU.BSUtil.setAll(a.length));for(var e=this.vwr.ms.at,g=this.vwr.ms.ac;0<=--g;)for(var f=e[g],h=b.nextSetBit(0);0<=
-h;h=b.nextSetBit(h+1))if(f.distance(a[h])<d){c.set(g);break}return c},"~N,~A,JU.BS");l(c$,"getMinMax",function(d,a){for(var b=null,c=null,e=0,g=null;;){if(JU.AU.isAF(d)){if(1140850707==a)break;b=d;e=b.length;if(0==e)break}else if(s(d,JU.Lst))if(c=d,e=c.size(),0==e){if(1140850707!=a)break}else{var f=c.get(0);if(8==f.tok)return this.getMinMaxPoint(c,a);if(4==f.tok&&f.value.startsWith("{")){b=JS.SV.ptValue(f);if(s(b,JU.P3))return this.getMinMaxPoint(c,a);if(s(b,JU.P4))return this.getMinMaxQuaternion(c,
-a);break}}else break;var h,k=!1;switch(a){case 1140850707:g=new java.util.Hashtable;f=h=0;break;case 32:k=!0;f=3.4028235E38;h=2147483647;break;case 64:f=-3.4028235E38;h=-2147483647;break;default:f=h=0}for(var j=0,l=0,n=!0,r=1140850707==a;0<=--e;){var p=null==c?JS.SV.vF:c.get(e),t=r?1:null==b?JS.SV.fValue(p):b[e];if(!Float.isNaN(t))switch(l++,a){case 160:case 192:j+=t*t;case 128:case 96:f+=t;break;case 1140850707:n=(new Boolean(n&2==p.tok)).valueOf();p=p.asString();t=g.get(p);g.put(p,null==t?new Integer(1):
-new Integer(t.intValue()+1));break;case 32:case 64:n=(new Boolean(n&2==p.tok)).valueOf(),k==t<f&&(f=t,n&&(h=p.intValue))}}if(1140850707==a)return g;if(0==l)break;switch(a){case 96:f/=l;break;case 192:if(1==l)break;f=Math.sqrt((j-f*f/l)/(l-1));break;case 32:case 64:if(n)return Integer.$valueOf(h);break;case 160:f=j}return Float.$valueOf(f)}return"NaN"},"~O,~N");l(c$,"getMinMaxPoint",function(d,a){var b=null,c=null,e=0;s(d,Array)?(b=d,e=b.length):s(d,JU.Lst)&&(c=d,e=c.size());if(null==c&&null==b)return"NaN";
-for(var g=new JU.P3,f=v(e,0),h=0;3>h;h++){for(var k=0;k<e;k++){var j=null==b?JS.SV.ptValue(c.get(k)):b[k];if(null==j)return"NaN";switch(h){case 0:f[k]=j.x;break;case 1:f[k]=j.y;break;case 2:f[k]=j.z}}k=this.getMinMax(f,a);if(!s(k,Number))return"NaN";k=k.floatValue();switch(h){case 0:g.x=k;break;case 1:g.y=k;break;case 2:g.z=k}}return g},"~O,~N");l(c$,"getMinMaxQuaternion",function(d,a){var b;switch(a){case 32:case 64:case 128:case 160:return"NaN"}for(;;){b=this.e.getQuaternionArray(d,1073742001);
-if(null==b)break;var c=v(1,0);b=JU.Quat.sphereMean(b,c,1E-4);switch(a){case 96:return b;case 192:return Float.$valueOf(c[0])}break}return"NaN"},"JU.Lst,~N");l(c$,"getPatternMatcher",function(){return null==this.pm?this.pm=J.api.Interface.getUtil("PatternMatcher",this.e.vwr,"script"):this.pm});l(c$,"opTokenFor",function(d){switch(d){case 1275069441:case 1275069446:return JS.T.tokenPlus;case 1275068931:return JS.T.tokenMinus;case 1275068929:return JS.T.tokenTimes;case 1275068930:return JS.T.tokenMul3;
-case 1275068928:return JS.T.tokenDivide}return null},"~N");l(c$,"setContactBitSets",function(d,a,b,c,e,g){var f,h;null==a?(a=JU.BSUtil.setAll(this.vwr.ms.ac),JU.BSUtil.andNot(a,this.vwr.slm.bsDeleted),a.andNot(d),f=!1):(h=JU.BSUtil.copy(d),h.or(a),h=this.vwr.ms.getModelBS(h,!1).cardinality(),f=1<h,g&&(1<h&&!this.e.tQuiet)&&this.e.showString(J.i18n.GT._("Note: More than one model is involved in this contact!")));if(!d.equals(a)){if(g=!b||d.cardinality()<a.cardinality())h=this.vwr.ms.getAtomsWithinRadius(c,
-d,f,Float.isNaN(c)?e:null),a.and(h);b&&(h=this.vwr.ms.getAtomsWithinRadius(c,a,f,Float.isNaN(c)?e:null),d.and(h),g||(h=this.vwr.ms.getAtomsWithinRadius(c,d,f,Float.isNaN(c)?e:null),a.and(h)),h=JU.BSUtil.copy(a),h.and(d),h.equals(d)?a.andNot(d):h.equals(a)&&d.andNot(a))}return a},"JU.BS,JU.BS,~B,~N,J.atomdata.RadiusData,~B")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,
-Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,
-Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
+"JS.ScriptMathProcessor,~A,~N");l(c$,"evaluateString",function(d,a,b){var c=d.getX(),e=0<b.length?JS.SV.sValue(b[0]):1275068932==a?"":"\n";switch(b.length){case 0:break;case 1:if(1073742335==b[0].tok)return d.addX(JS.SV.getVariable(JU.PT.getTokens(c.asString())));break;case 2:if(7==c.tok)break;if(1275069447==a){c=JS.SV.getVariable(JU.PT.split(JU.PT.rep(c.value,"\n\r","\n").$replace("\r","\n"),"\n"));break}default:return!1}if(7==c.tok&&1275068932!=a&&(1275069447!=a||2==b.length))return d.addX(c),this.evaluateList(d,
+a,b);b=1275069447==a&&10==c.tok||1275068932==a&&7==c.tok?null:JS.SV.sValue(c);switch(a){case 1275069447:if(10==c.tok){e=c.value;c=this.vwr.ms.mc;b=new JU.Lst;for(a=0;a<c;a++){var g=this.vwr.getModelUndeletedAtomsBitSet(a);g.and(e);b.addLast(JS.SV.getVariable(g))}return d.addXList(b)}return d.addXAS(JU.PT.split(b,e));case 1275069446:return 0<b.length&&"\n"==b.charAt(b.length-1)&&(b=b.substring(0,b.length-1)),d.addXStr(JU.PT.rep(b,"\n",e));case 1275068932:if(null!=b)return d.addXStr(JU.PT.trim(b,e));
+c=JS.SV.strListValue(c);for(a=c.length;0<=--a;)c[a]=JU.PT.trim(c[a],e);return d.addXAS(c)}return d.addXStr("")},"JS.ScriptMathProcessor,~N,~A");l(c$,"evaluateSubstructure",function(d,a,b,c){if(0==a.length||c&&1<a.length)return!1;var e=new JU.BS,g=JS.SV.sValue(a[0]);if(0<g.length)try{var f=c?d.getX().value:2==a.length&&10==a[1].tok?a[1].value:null,e=this.vwr.getSmilesMatcher().getSubstructureSet(g,this.vwr.ms.at,this.vwr.ms.ac,f,134218757==b?1:2)}catch(h){if(C(h,Exception))this.e.evalError(h.getMessage(),
+null);else throw h;}return d.addXBs(e)},"JS.ScriptMathProcessor,~A,~N,~B");l(c$,"evaluateSymop",function(d,a,b){b=b?d.getX():null;if(null!=b&&10!=b.tok)return!1;b=null==b?null:b.value;null==b&&1==this.vwr.ms.mc&&(b=this.vwr.getModelUndeletedAtomsBitSet(0));var c=a.length;if(0==c){if(b.isEmpty())return!1;a=JU.PT.split(JU.PT.trim(this.vwr.getSymTemp().getSpaceGroupInfo(this.vwr.ms,null,this.vwr.ms.at[b.nextSetBit(0)].mi).get("symmetryInfo"),"\n"),"\n");b=new JU.Lst;for(var e=0,g=a.length;e<g;e++)b.addLast(JU.PT.split(a[e],
+"\t"));return d.addXList(b)}var e=null,g=-2147483648,f=0;switch(a[0].tok){case 4:e=JS.SV.sValue(a[0]);f++;break;case 12:e=a[0].escape();f++;break;case 2:g=a[0].asInt(),f++}null==b&&(f<c&&10==a[f].tok&&(b=new JU.BS).or(a[f].value),f+1<c&&10==a[f+1].tok&&(null==b?b=new JU.BS:b).or(a[f+1].value));var h=null,k=null;null!=(h=c>f?d.ptValue(a[f],b):null)&&f++;null!=(k=c>f?d.ptValue(a[f],b):null)&&f++;var j=null!=k&&a.length>f&&-2147483648==g&&2==a[f].tok?a[f].intValue:0;0<j&&f++;-2147483648==g&&(g=0);c=
+c==f?null!=k?"all":null!=h?"point":"matrix":JS.SV.sValue(a[f++]).toLowerCase();return null!=b&&!b.isEmpty()&&f==a.length&&d.addXObj(this.vwr.getSymTemp().getSymmetryInfoAtom(this.vwr.ms,b.nextSetBit(0),e,g,h,k,c,0,0,j))},"JS.ScriptMathProcessor,~A,~B");l(c$,"evaluateTensor",function(d,a){var b=d.getX();if(2<a.length||10!=b.tok)return!1;var b=b.value,c=0==a.length?null:JS.SV.sValue(a[0]).toLowerCase(),e=this.vwr.getNMRCalculation();if("unique".equals(c))return d.addXBs(e.getUniqueTensorSet(b));var g=
+2>a.length?null:JS.SV.sValue(a[1]).toLowerCase();return d.addXList(e.getTensorInfo(c,g,b))},"JS.ScriptMathProcessor,~A");l(c$,"evaluateUserFunction",function(d,a,b,c,e){var g=null;if(e)switch(g=d.getX(),g.tok){case 10:break;case 6:if(0<b.length)return!1;g=g.getMap().get(a);return null==g?d.addXStr(""):d.addX(g);default:return!1}a=a.toLowerCase();d.wasX=!1;for(var f=new JU.Lst,h=0;h<b.length;h++)f.addLast(b[h]);if(e)return d.addXObj(this.e.getBitsetProperty(g.value,c,null,null,g.value,x(-1,[a,f]),
+!1,g.index,!1));a=this.e.getUserFunctionResult(a,f,null);return null==a?!1:d.addX(a)},"JS.ScriptMathProcessor,~S,~A,~N,~B");l(c$,"evaluateWithin",function(d,a){if(1>a.length||5<a.length)return!1;var b=a.length;if(1==b&&10==a[0].tok)return d.addX(a[0]);var c=0,e=a[0].value,g=""+e,f=a[0].tok;4==f&&(f=JS.T.getTokFromName(g));var h=this.vwr.ms,k=!1,j=!1,l=!1,n=!1,r=null;switch(f){case 1648363544:k=!0,e=null;case 3:case 2:n=!0;if(2>b||3==b&&7==a[1].tok&&7!=a[2].tok)return!1;c=k?100:JS.SV.fValue(a[0]);
+switch(f=a[1].tok){case 1073742335:case 1073742334:j=a[1].asBoolean();2<b&&JS.SV.sValue(a[2]).equalsIgnoreCase("unitcell")&&(f=1814695966);b=0;break;case 4:f=JS.SV.sValue(a[1]);if(f.startsWith("$"))return d.addXBs(this.getAtomsNearSurface(c,f.substring(1)));if(f.equalsIgnoreCase("group"))l=!0,f=1086324742;else if(f.equalsIgnoreCase("vanderwaals")||f.equalsIgnoreCase("vdw"))e=null,k=!0,f=1648363544;else if(f.equalsIgnoreCase("unitcell"))f=1814695966;else return!1}break;case 7:1==b&&(e=a[0].asString(),
+f=0);break;case 1073742328:return 3==b&&s(a[1].value,JU.BS)&&s(a[2].value,JU.BS)&&d.addXBs(this.vwr.getBranchBitSet(a[2].value.nextSetBit(0),a[1].value.nextSetBit(0),!0));case 134218757:case 1237320707:case 134218756:c=null;e=!0;switch(b){case 2:break;case 3:if(e=10==a[2].tok)c=a[2].value;break;default:e=!1}e||this.e.invArg();return d.addXObj(this.e.getSmilesExt().getSmilesMatches(JS.SV.sValue(a[1]),null,c,null,134218756==f?2:1,d.asBitSet,!1))}if(s(e,String)){if(0==f){f=1073742362;if(2<b)return!1;
+b=2}}else if(!n)return!1;switch(b){case 1:switch(f){case 136314895:case 2097184:case 1678381065:return d.addXBs(h.getAtoms(f,null));case 1073741863:return d.addXBs(h.getAtoms(f,""));case 1073742362:return d.addXBs(h.getAtoms(1086324744,g))}return!1;case 2:switch(f){case 1073742362:f=1086324744;break;case 1073741824:case 1086326786:case 1086326785:case 1073741863:case 1086324744:case 1111490587:case 1073742128:case 1073741925:case 1073742189:return d.addXBs(this.vwr.ms.getAtoms(f,JS.SV.sValue(a[a.length-
+1])))}break;case 3:switch(f){case 1073742335:case 1073742334:case 1086324742:case 1648363544:case 1814695966:case 134217750:case 134219265:case 1073742329:case 8:case 7:break;case 1086324744:g=JS.SV.sValue(a[2]);break;default:return!1}}var p=null,e=b=null,t=a.length-1;switch(a[t].tok){case 9:p=a[t].value;break;case 8:b=a[t].value;JS.SV.sValue(a[1]).equalsIgnoreCase("hkl")&&(p=this.e.getHklPlane(b));break;case 7:e=2==t&&7==a[1].tok?a[1].getList():null,b=2==t?JS.SV.ptValue(a[1]):1==t?JU.P3.new3(NaN,
+0,0):null}if(null!=p)return d.addXBs(h.getAtomsNearPlane(c,p));h=10==a[t].tok?a[t].value:null;if(0<t&&null==b&&null==e&&null==h)return!1;if(1814695966==f)return(null!=h||null!=b)&&d.addXObj(this.vwr.ms.getUnitCellPointsWithin(c,h,b,j));if(null!=b||null!=e){if(7==a[t].tok){g=a[t].getList();j=new JU.Lst;k=new J.bspt.Bspt(3,0);if(null!=b&&Float.isNaN(b.x)){e=Array(g.size());for(f=e.length;0<=--f;){l=JS.SV.ptValue(g.get(f));if(null==l)return!1;b=new JU.Point3fi;b.setT(l);b.i=f;e[f]=b;k.addTuple(b)}l=
+k.allocateCubeIterator();n=JU.BSUtil.newBitSet2(0,g.size());for(f=e.length;0<=--f;){l.initialize(b=e[f],c,!1);k=c*c;for(r=0;l.hasMoreElements();)g=l.nextElement(),n.get(g.i)&&(g.distanceSquared(b)<=k&&1<++r)&&n.clear(g.i)}for(f=n.nextSetBit(0);0<=f;f=n.nextSetBit(f+1))j.addLast(JU.P3.newP(e[f]));return d.addXList(j)}if(0==c){if(null==e){k=3.4028235E38;e=null;for(f=g.size();0<=--f;)j=JS.SV.ptValue(g.get(f)),c=j.distanceSquared(b),c<k&&(e=j,k=c);return null==e?d.addXStr(""):d.addXPt(e)}l=I(e.size(),
+0);for(f=l.length;0<=--f;){k=3.4028235E38;n=-1;b=JS.SV.ptValue(e.get(f));for(r=g.size();0<=--r;)j=JS.SV.ptValue(g.get(r)),c=j.distanceSquared(b),c<k&&(n=r,k=c);l[f]=n}return d.addXAI(l)}for(f=g.size();0<=--f;)e=JS.SV.ptValue(g.get(f)),k.addTuple(e);l=k.allocateCubeIterator();l.initialize(b,c,!1);for(k=c*c;l.hasMoreElements();)g=l.nextElement(),g.distanceSquared(b)<=k&&j.addLast(g);l.release();return d.addXList(j)}return d.addXBs(this.vwr.getAtomsNearPt(c,b))}if(1086324744==f)return d.addXBs(this.vwr.ms.getSequenceBits(g,
+h,new JU.BS));null==h&&(h=new JU.BS);if(!n)return d.addXBs(this.vwr.ms.getAtoms(f,h));if(l)return d.addXBs(this.vwr.getGroupsWithin(A(c),h));k&&(r=new J.atomdata.RadiusData(null,10<c?c/100:c,10<c?J.atomdata.RadiusData.EnumType.FACTOR:J.atomdata.RadiusData.EnumType.OFFSET,J.c.VDW.AUTO),0>c&&(c=0));return d.addXBs(this.vwr.ms.getAtomsWithinRadius(c,h,j,r))},"JS.ScriptMathProcessor,~A");l(c$,"evaluateWrite",function(d,a){switch(a.length){case 0:return!1;case 1:if(!a[0].asString().toUpperCase().equals("PNGJ"))break;
+return d.addXMap(this.vwr.fm.getFileAsMap(null))}return d.addXStr(this.e.getCmdExt().dispatch(134221856,!0,a))},"JS.ScriptMathProcessor,~A");l(c$,"getAtomsNearSurface",function(d,a){var b=x(-1,[a,null,null]);if(this.e.getShapePropertyData(24,"getVertices",b))return this.getAtomsNearPts(d,b[1],b[2]);b[1]=Integer.$valueOf(0);b[2]=Integer.$valueOf(-1);return this.e.getShapePropertyData(22,"getCenter",b)?this.vwr.getAtomsNearPt(d,b[2]):new JU.BS},"~N,~S");l(c$,"getAtomsNearPts",function(d,a,b){var c=
+new JU.BS;if(0==a.length||null!=b&&b.isEmpty())return c;null==b&&(b=JU.BSUtil.setAll(a.length));for(var e=this.vwr.ms.at,g=this.vwr.ms.ac;0<=--g;)for(var f=e[g],h=b.nextSetBit(0);0<=h;h=b.nextSetBit(h+1))if(f.distance(a[h])<d){c.set(g);break}return c},"~N,~A,JU.BS");l(c$,"getMinMax",function(d,a){for(var b=null,c=null,e=0,g=null;;){if(JU.AU.isAF(d)){if(1140850707==a)break;b=d;e=b.length;if(0==e)break}else if(s(d,JU.Lst))if(c=d,e=c.size(),0==e){if(1140850707!=a)break}else{var f=c.get(0);if(8==f.tok)return this.getMinMaxPoint(c,
+a);if(4==f.tok&&f.value.startsWith("{")){b=JS.SV.ptValue(f);if(s(b,JU.P3))return this.getMinMaxPoint(c,a);if(s(b,JU.P4))return this.getMinMaxQuaternion(c,a);break}}else break;var h,k=!1;switch(a){case 1140850707:g=new java.util.Hashtable;f=h=0;break;case 32:k=!0;f=3.4028235E38;h=2147483647;break;case 64:f=-3.4028235E38;h=-2147483647;break;default:f=h=0}for(var j=0,l=0,n=!0,r=1140850707==a;0<=--e;){var p=null==c?JS.SV.vF:c.get(e),t=r?1:null==b?JS.SV.fValue(p):b[e];if(!Float.isNaN(t))switch(l++,a){case 160:case 192:j+=
+t*t;case 128:case 96:f+=t;break;case 1140850707:n=(new Boolean(n&2==p.tok)).valueOf();p=p.asString();t=g.get(p);g.put(p,null==t?new Integer(1):new Integer(t.intValue()+1));break;case 32:case 64:n=(new Boolean(n&2==p.tok)).valueOf(),k==t<f&&(f=t,n&&(h=p.intValue))}}if(1140850707==a)return g;if(0==l)break;switch(a){case 96:f/=l;break;case 192:if(1==l)break;f=Math.sqrt((j-f*f/l)/(l-1));break;case 32:case 64:if(n)return Integer.$valueOf(h);break;case 160:f=j}return Float.$valueOf(f)}return"NaN"},"~O,~N");
+l(c$,"getMinMaxPoint",function(d,a){var b=null,c=null,e=0;s(d,Array)?(b=d,e=b.length):s(d,JU.Lst)&&(c=d,e=c.size());if(null==c&&null==b)return"NaN";for(var g=new JU.P3,f=v(e,0),h=0;3>h;h++){for(var k=0;k<e;k++){var j=null==b?JS.SV.ptValue(c.get(k)):b[k];if(null==j)return"NaN";switch(h){case 0:f[k]=j.x;break;case 1:f[k]=j.y;break;case 2:f[k]=j.z}}k=this.getMinMax(f,a);if(!s(k,Number))return"NaN";k=k.floatValue();switch(h){case 0:g.x=k;break;case 1:g.y=k;break;case 2:g.z=k}}return g},"~O,~N");l(c$,
+"getMinMaxQuaternion",function(d,a){var b;switch(a){case 32:case 64:case 128:case 160:return"NaN"}for(;;){b=this.e.getQuaternionArray(d,1073742001);if(null==b)break;var c=v(1,0);b=JU.Quat.sphereMean(b,c,1E-4);switch(a){case 96:return b;case 192:return Float.$valueOf(c[0])}break}return"NaN"},"JU.Lst,~N");l(c$,"getPatternMatcher",function(){return null==this.pm?this.pm=J.api.Interface.getUtil("PatternMatcher",this.e.vwr,"script"):this.pm});l(c$,"opTokenFor",function(d){switch(d){case 1275069441:case 1275069446:return JS.T.tokenPlus;
+case 1275068931:return JS.T.tokenMinus;case 1275068929:return JS.T.tokenTimes;case 1275068930:return JS.T.tokenMul3;case 1275068928:return JS.T.tokenDivide}return null},"~N");l(c$,"setContactBitSets",function(d,a,b,c,e,g){var f,h;null==a?(a=JU.BSUtil.setAll(this.vwr.ms.ac),JU.BSUtil.andNot(a,this.vwr.slm.bsDeleted),a.andNot(d),f=!1):(h=JU.BSUtil.copy(d),h.or(a),h=this.vwr.ms.getModelBS(h,!1).cardinality(),f=1<h,g&&(1<h&&!this.e.tQuiet)&&this.e.showString(J.i18n.GT._("Note: More than one model is involved in this contact!")));
+if(!d.equals(a)){if(g=!b||d.cardinality()<a.cardinality())h=this.vwr.ms.getAtomsWithinRadius(c,d,f,Float.isNaN(c)?e:null),a.and(h);b&&(h=this.vwr.ms.getAtomsWithinRadius(c,a,f,Float.isNaN(c)?e:null),d.and(h),g||(h=this.vwr.ms.getAtomsWithinRadius(c,d,f,Float.isNaN(c)?e:null),a.and(h)),h=JU.BSUtil.copy(a),h.and(d),h.equals(d)?a.andNot(d):h.equals(a)&&d.andNot(a))}return a},"JU.BS,JU.BS,~B,~N,J.atomdata.RadiusData,~B")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,
+Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,
+Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
